@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::PerinciSubGetArgsArgv::get_args_from_argv;
 
-our $VERSION = 0.001; # VERSION
+our $VERSION = 0.002; # VERSION
 
 our $results = [
   [
@@ -8,28 +8,44 @@ our $results = [
     "OK",
     [
       {
-        dataset    => "2 known args + 2 args positional",
-        errors     => 2.7e-07,
-        rate       => 4600,
+        dataset    => "2 known args + 2 args named",
+        errors     => 2.1e-07,
+        rate       => 3920,
         samples    => 20,
-        time       => 220,
+        time       => 255,
         vs_slowest => 1,
       },
+      {
+        dataset    => "2 known args + 2 args positional",
+        errors     => 2.5e-07,
+        rate       => 4600,
+        samples    => 23,
+        time       => 220,
+        vs_slowest => 1.2,
+      },
+      {
+        dataset    => "meta norm + 2 known args + 2 args named",
+        errors     => 2.7e-07,
+        rate       => 5000,
+        samples    => 20,
+        time       => 200,
+        vs_slowest => 1.3,
+      },
       {
         dataset    => "2 known args + 0 args",
         errors     => 4.3e-07,
         rate       => 5300,
         samples    => 20,
         time       => 190,
-        vs_slowest => 1.2,
+        vs_slowest => 1.3,
       },
       {
         dataset    => "meta norm + 2 known args + 2 args positional",
         errors     => 2.1e-07,
-        rate       => 6100,
+        rate       => 6000,
         samples    => 20,
-        time       => 160,
-        vs_slowest => 1.3,
+        time       => 170,
+        vs_slowest => 1.5,
       },
       {
         dataset    => "meta norm + 2 known args + 0 args",
@@ -37,15 +53,23 @@ our $results = [
         rate       => 7400,
         samples    => 20,
         time       => 140,
-        vs_slowest => 1.6,
+        vs_slowest => 1.9,
       },
       {
         dataset    => "0 known args + 0 args",
-        errors     => 2.7e-08,
-        rate       => 19800,
+        errors     => 1.1e-07,
+        rate       => 20000,
         samples    => 20,
-        time       => 50.5,
-        vs_slowest => 4.35,
+        time       => 50,
+        vs_slowest => 5.1,
+      },
+      {
+        dataset    => "meta norm + 0 known args + 0 args",
+        errors     => 4.5e-11,
+        rate       => 28815,
+        samples    => 20,
+        time       => 34.705,
+        vs_slowest => 7.3581,
       },
     ],
     {
@@ -149,7 +173,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2468.231,
+                                              speed                        => 1706.097,
                                               stepping                     => 7,
                                             },
                                             {
@@ -244,7 +268,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2394.818,
+                                              speed                        => 2328.027,
                                               stepping                     => 7,
                                             },
                                             {
@@ -339,7 +363,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 1803.918,
+                                              speed                        => 2011.291,
                                               stepping                     => 7,
                                             },
                                             {
@@ -434,11 +458,11 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2588.378,
+                                              speed                        => 2282.806,
                                               stepping                     => 7,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.157420873641968,
+      "func.elapsed_time"              => 0.297473907470703,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__" => 1.041,
@@ -450,7 +474,7 @@ our $results = [
                                             "Sys::Info" => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0], "dataset", [0 .. 4]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0], "dataset", [0 .. 7]],
       "func.platform_info"             => {
                                             archname => "x86_64",
                                             codename => "sonya",
@@ -476,13 +500,13 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::PerinciSubGetArgsArgv::get_args_from_argv",
-      "func.scenario_module_md5sum"    => "1c907577fc7ce9190e1f25ef768b3caa",
-      "func.scenario_module_mtime"     => 1542878997,
-      "func.scenario_module_sha1sum"   => "29a3d4dfde13757ec63371f5e32f30f8fb7aec4e",
-      "func.scenario_module_sha256sum" => "44a1cb942eef07650590e9e69207c2bf91512a6d82ee5e4ccfff024b959ae54e",
-      "func.time_end"                  => 1542879078.07741,
+      "func.scenario_module_md5sum"    => "048e81e43e0dbe744a09b749e9c803c2",
+      "func.scenario_module_mtime"     => 1542879500,
+      "func.scenario_module_sha1sum"   => "a46d4fda30ba25c963a10216c8144fcc87fd2ca3",
+      "func.scenario_module_sha256sum" => "7194768d881d9d62d22fceb57ea9ea795b64d82f07d05593dc18d6e2e8e14e91",
+      "func.time_end"                  => 1542879554.52802,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1542879077.91999,
+      "func.time_start"                => 1542879554.23055,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "/s", "\x{3BC}s"],
       "table.fields"                   => ["dataset", "rate", "time", "vs_slowest", "errors", "samples"],
